Module: Kernel
- Defined in:
- lib/inline_forms.rb,
lib/app/helpers/inline_forms_helper.rb
Overview
make the current method and the calling method available http://www.ruby-forum.com/topic/75258 supposedly, this is fixed in 1.9
make the current method and the calling method available http://www.ruby-forum.com/topic/75258 supposedly, this is fixed in 1.9